function initHeading()
{
	// Define the callbacks for the asyncRequest
	var callbacks = {
		
		success : function (o) {

			YAHOO.log("RAW JSON DATA: " + o.responseText);

			// Process the JSON data returned from the server
			var data;
			try {
				data = YAHOO.lang.JSON.parse(o.responseText);
			}
			catch (x) {
				YAHOO.log("ERROR: JSON Parse failed!");

				// Retry
				setTimeout("initHeading()", 5000);

				return;
			}

			YAHOO.log("PARSED DATA: " + YAHOO.lang.dump(data));

			// Get config
			var config = data.ConfigHeading;
			if (config == null) return;
			
			// -- Antenna List --
			if (config.Antenna.List != null)
			{
				var names = new Array();
				
				for (i in config.Antenna.List)
				{	
					names.push(config.Antenna.List[i].AntennaName);
				}
				
				addFieldOptions('Heading-Field-Antenna1Name', names, names);
				addFieldOptions('Heading-Field-Antenna2Name', names, names);
			}

			// -- Antenna 1 Name --
			setFieldValue('Heading-Field-Antenna1Name', config.Antenna.Antenna1Name);

			// -- Antenna 2 Name --
			if (ProFlex.isDuo()) {
				setItemDisplayed('Heading-Label-Antenna2Name', true);
				setItemDisplayed('Heading-Field-Antenna2Name', true);
				setFieldValue('Heading-Field-Antenna2Name', config.Antenna.Antenna2Name);
				setItemText('Heading-Label-Antenna1Name',getResource('Heading-Ressource-Antenna1Name'));
			} else {
				removeFieldFromPost('Heading-Field-Antenna2Name');
			}
			
			// -- FastOutput --
			setFieldChecked('Heading-Field-FastOutput', (config.FastOutput == 1));
			
			// -- Position Mask --
			setFieldValue('Heading-Field-ElevationMask', config.PositionElevationMask);
			
			// -- GLONASS --
			setFieldChecked('Heading-Field-GLONASS', (config.SatelliteGlonass == 1));
			
			// -- SBAS --
			setFieldChecked('Heading-Field-SBAS', (config.SatelliteSbas == 1));
			
			// -- Mode --
			if (!ProFlex.isDuo())
			{
				var elSel = document.getElementById('Heading-Field-Mode');
				elSel.remove(1);
			}
			selectValueElseDefault('Heading-Field-Mode', config.Heading.Heading, 0);
			
			// -- Input Port --
			setFieldVisible('Heading-Field-InputPort', (config.Heading.Heading == 2));
			if (config.Heading.HeadingPort == 'H')
			{
				setFieldValue('Heading-Field-InputPort', 'A');
			}
			else
			{
				setFieldValue('Heading-Field-InputPort', config.Heading.HeadingPort);
			}
			
			// -- Baseline Length --
			setFieldValueAsDistance('Heading-Field-BaselineLength', config.Heading.BaselineLength);
			setFieldVisible('Heading-Field-BaselineLength', (config.Heading.BaselineLength != 0));
			
			// -- Auto Calibration --
			setFieldChecked('Heading-Field-AutoCalibration', (config.Heading.BaselineLength == 0));
			
			// -- Azimuth Offset --
			setFieldValueAsSimpleAngle('Heading-Field-AzimuthOffset', config.Heading.AzimuthOffset);
			
			// -- Elevation Offset --
			setFieldValueAsSimpleAngle('Heading-Field-ElevationOffset', config.Heading.ElevationOffset);
			
			// -- Maximum Baseline Elevation --
			setFieldValueAsSimpleAngleInteger('Heading-Field-MaximumBaselineElevation', config.Heading.MaximumBaselineElevation);
			
			// -- Maximum Baseline Error Length --
			setFieldValueAsDistance('Heading-Field-MaximumBaselineErrorLength', config.Heading.MaximumBaselineErrorLength);

			// Show form
			showConfigForm();
		},

		failure : function (o) {
			if (!YAHOO.util.Connect.isCallInProgress(o)) {
				YAHOO.log("ERROR: Async call failed!");
			}

			// Retry
			setTimeout("initRoverSetup()", 5000);
		},

		timeout : 10000,
		cache : false
    };

	// Make the call to the server for JSON data
	YAHOO.util.Connect.asyncRequest('GET', getConfigHeading, callbacks);
	
	// Units changed
	YAHOO.util.Event.addListener('distances', 'change', onDistanceUnitChanged);
	
	// Heading Mode changed
	YAHOO.util.Event.addListener('Heading-Field-Mode', 'change', onModeChanged);
	
	// Distance changed
	YAHOO.util.Event.addListener('Heading-Field-AutoCalibration', 'click', onAutoCalibrationClick);
	YAHOO.util.Event.addListener('Heading-Field-BaselineLength', 'change', onDistanceValueChanged);
	YAHOO.util.Event.addListener('Heading-Field-MaximumBaselineErrorLength', 'change', onDistanceValueChanged);
	
	// Degree changed
	YAHOO.util.Event.addListener('Heading-Field-AzimuthOffset', 'change', onSimpleAngleValueChanged);
	YAHOO.util.Event.addListener('Heading-Field-ElevationOffset', 'change', onSimpleAngleValueChanged);
	YAHOO.util.Event.addListener('Heading-Field-MaximumBaselineElevation', 'change', onSimpleAngleIntegerValueChanged);
	
	//Validators
	makeFieldValidator('Heading-Field-BaselineLength', 'validating_BaselineLength');
	makeFieldValidator('Heading-Field-AzimuthOffset', 'validating_AzimuthOffset');
	makeFieldValidator('Heading-Field-ElevationOffset', 'validating_ElevationOffset');
	makeFieldValidator('Heading-Field-MaximumBaselineElevation', 'validating_MaximumBaselineElevation');
	makeFieldValidator('Heading-Field-MaximumBaselineErrorLength', 'validating_MaximumBaselineErrorLength');
}

function getPrefixName()
{
	return "Heading";
}

function onModeChanged(ev)
{
	var field = YAHOO.util.Event.getTarget(ev);
	
	// -- Input Port --
	setFieldVisible('Heading-Field-InputPort', (field.value == 2));
}

function onAutoCalibrationClick(ev)
{
	var field = YAHOO.util.Event.getTarget(ev);
	
	// -- Baseline Length --
	if (isFieldChecked(field))
	{
		setFieldValueAsDistance('Heading-Field-BaselineLength', 0);
		setFieldVisible('Heading-Field-BaselineLength', false);
	}
	else
	{
		setFieldVisible('Heading-Field-BaselineLength', true);
	}	
}

function onDistanceUnitChanged()
{
	updateFieldValueAsDistance('Heading-Field-BaselineLength');
	updateFieldValueAsDistance('Heading-Field-MaximumBaselineErrorLength');
}

function onDistanceValueChanged(ev)
{
	var field = YAHOO.util.Event.getTarget(ev);
	updateFieldValueAsDistance(field.id);
}

function onSimpleAngleValueChanged(ev)
{
	var field = YAHOO.util.Event.getTarget(ev);
	updateFieldValueAsSimpleAngle(field.id);
}

function onSimpleAngleIntegerValueChanged(ev)
{
	var field = YAHOO.util.Event.getTarget(ev);
	updateFieldValueAsSimpleAngleInteger(field.id);
}

